from setuptools import setup

setup(name='final_distributions',
      version='1.8',
      description='Binomial & Gaussian distributions',
      packages=['final_distributions'],
      author = 'Franklin Rivers',
      author_email = 'letsT17@gmail.com',
      zip_safe=False)
